@@ -1,8 +1,11 @@
 #!/bin/sh -e
-# Copyright (c) 2002-2003 Martin A. Godisch <martin@godisch.de>
+# Copyright (c) 2002-2007 Martin A. Godisch <martin@godisch.de>
+
+export LC_ALL=C
 
 test -e latrine.c
 umask 022
+date -R > released
 aclocal -I /usr/share/autoconf-archive
 autoheader -Wall
 autoconf -Wall
