@@ -1,6 +1,6 @@
 /* vim: set noet ts=4:
  *
- * Copyright (c) 2002-2006 Martin A. Godisch <martin@godisch.de>.
+ * Copyright (c) 2002-2007 Martin A. Godisch <martin@godisch.de>.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU General Public License as published by the Free Software
@@ -19,18 +19,27 @@
 #define _DATA_H
 
 #include <stdlib.h>
+#include <time.h>
+#include <md5.h>
 
 #define DEFAULT_RANDCOUNT   10
 #define DEFAULT_WORDLIMIT 1000
-#define WORDLIST_VERSION     2
+#define WORDLIST_VERSION     3
+#define HISTSIZE            32
+#define DIGEST_ALIGN         4
 #define HEADER            "# LaTrine wordlist file, version = %d.\n"
 
+struct Tlang {
+	char *c;
+	struct Tlang *next;
+};
+
 struct word {
-	char     *lang[2];
-	unsigned long index;
-	time_t   timestamp;
-	double   rate;
-	size_t   pos;
+	struct Tlang *lang[2];
+	char   history[HISTSIZE + 1];
+	time_t timestamp;
+	short  rate;
+	size_t pos;
 };
 
 extern char   *dictfile;
@@ -38,6 +47,7 @@ extern char   *wordfile;
 extern size_t randcount;
 extern size_t wordlimit;
 
+void   free_langlist(struct word*);
 int    load_wordlist(void);
 int    save_wordlist(void);
 size_t get_dictcount(void);
