@@ -1,6 +1,6 @@
 /* vim: set noet ts=4:
  *
- * Copyright (c) 2002-2006 Martin A. Godisch <martin@godisch.de>.
+ * Copyright (c) 2002-2007 Martin A. Godisch <martin@godisch.de>.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU General Public License as published by the Free Software
@@ -20,6 +20,7 @@
 
 #include <assert.h>
 #include <config.h>
+#include <stdio.h>
 
 #include <libintl.h>
 #define _(string) gettext(string)
@@ -30,7 +31,7 @@
 
 #include <errno.h>
 #include <string.h>
-extern int  debug;
+extern FILE *debug;
 extern void errmsg(const char*, ...);
 
 #endif
